@@ -15,7 +15,7 @@ use XML::Simple;
 use Time::HiRes;
 use Carp;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 NAME
 
@@ -218,7 +218,7 @@ The second argument is the user name.
 The third argument is the password.
 
 Various options can be specified as
-name value pairs following the password.
+name/value pairs following the password.
 For a list of options refer to L</set>.
 
 B<Syntax>
@@ -333,53 +333,13 @@ sub traceContent {
 
 =head2 call
 
-This method calls a 
-L<Scripted Web Service|http://wiki.servicenow.com/index.php?title=Scripted_Web_Services>.
-The input parameters can be passed in as list of key/value pairs
-or as a hash reference.
-In a list context this method will return a list of key/value pairs.
-In a scalar context it will return a hash reference.
-
-Use of this method requires the C<soap_script> role and activation of the 
-"Web Services Provider - Scripted" plugin.
-
-B<Syntax>
-
-    my %outputs = $sn->call($name, %inputs);
-    my $outputs = $sn->call($name, $inputs); # $inputs must be a hash reference
-
-B<Example>
-
-    my %outputs = $sn->call('OrderBlackBerry',
-        phone_number => '555-555-5555',
-        requested_for => 'Fred Luddy');
-    print "created request ", $outputs{request_number}, "\n";
+This method is deprecated and will be removed in a future release.
+This is an alias for the L<execute> method described below.
 
 =cut
 
 sub call {
-    my $session = shift;
-    my $function = shift;
-    my $trace = $session->{trace};
-    my $baseurl = $session->{url};
-    my $endpoint = "$baseurl/$function.do?SOAP";
-    my $client = $session->{client};
-    my @params = 
-        (@_ && ref $_[0] eq 'HASH') ?
-        ServiceNow::SOAP::_params(%{$_[0]}) :
-        ServiceNow::SOAP::_params(@_);
-    $session->traceBefore($function);
-    $context = $session;
-    my $som = $client->endpoint($endpoint)->call('execute' => @params);
-    Carp::croak $som->faultdetail if $som->fault;
-    $session->traceAfter('');
-    my $response = $som->body->{executeResponse};
-    if (ref $response eq 'HASH') {
-        return wantarray ? %{$response} : $response;
-    }
-    else {  
-        return wantarray ? () : undef;
-    }
+    execute(@_);
 }
 
 =head2 connect
@@ -418,6 +378,64 @@ sub connect {
     return $session;
 }
 
+=head2 execute
+
+This method calls the "execute" function on a 
+L<Scripted Web Service|http://wiki.servicenow.com/index.php?title=Scripted_Web_Services>.
+The first argument is the name of the Scripted Web Service.
+This may be followed by input parameters 
+which can be passed in as list of key/value pairs
+or as a hash reference.
+In a list context this method returns the output parameters as a list of key/value pairs.
+In a scalar context it returns the output parameters as a hash reference.
+
+Use of this method requires the C<soap_script> role and activation of the 
+"Web Services Provider - Scripted" plugin.
+
+B<Syntax>
+
+    my %outputs = $sn->execute($name, %inputs); # %inputs is a list or hash
+    my $outputs = $sn->execute($name, $inputs); # $inputs is a hash reference
+
+B<Examples>
+
+    my %outputs = $sn->execute('GetProperty', property => 'glide.product.description');
+    my $value = $outputs{'property'};
+
+    my $outputs = $sn->execute('InstanceInfo');
+    my @keys = keys %{$outputs->{result}};
+    foreach my $key (@keys) {
+        my $value = $outputs->{result}->{$key};
+        print "$key=$value\n";
+    }
+    
+=cut
+
+sub execute {
+    my $session = shift;
+    my $function = shift;
+    my $trace = $session->{trace};
+    my $baseurl = $session->{url};
+    my $endpoint = "$baseurl/$function.do?SOAP";
+    my $client = $session->{client};
+    my @params = 
+        (@_ && ref $_[0] eq 'HASH') ?
+        ServiceNow::SOAP::_params(%{$_[0]}) :
+        ServiceNow::SOAP::_params(@_);
+    $session->traceBefore($function);
+    $context = $session;
+    my $som = $client->endpoint($endpoint)->call('execute' => @params);
+    Carp::croak $som->faultdetail if $som->fault;
+    $session->traceAfter('');
+    my $response = $som->body->{executeResponse};
+    if (ref $response eq 'HASH') {
+        return wantarray ? %{$response} : $response;
+    }
+    else {  
+        return wantarray ? () : undef;
+    }
+}
+
 =head2 loadSession
 
 This method loads the session information (I<i.e.> cookies) from a file.
@@ -1231,7 +1249,7 @@ C<item_option_new>,
 C<sc_item_option> and
 C<sc_item_option_mtom>.
 
-Each hash contains the following four fields:
+Each hash contains the following five fields:
 
 =over
 
@@ -1923,7 +1941,7 @@ B<Syntax>
 B<Example>
 
 This example returns a list of all records in the C<cmdb_ci_computer> table,
-but only 5 columns are returnd.
+but only 5 columns are returned.
 
     my $tbl = $sn->table("cmdb_ci_computer");
     my $qry = $tbl->query()->include(
